#include <security/pam_appl.h>
#include <security/pam_modules.h>
#include <security/pam_ext.h>
#include <sys/stat.h>
#include <stdbool.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

const char* LOG_FILE="/var/log/eta-kisit.log";

void print_log(const char* msg) {
    FILE* f = fopen(LOG_FILE, "a");
    if (f != NULL) {
        fprintf(f, msg);
    }
    fclose(f);
}

void print_status(const char* stage, const char* user, int flags, int argc, const char **argv) {
    char msg[1024];
    sprintf(msg, "pam | %s %s, flags:%d, argc:%d \n", user, stage, flags, argc);
    print_log(msg);

    while (argc > 0) {
        argc--;
        char argstring[1024];
        sprintf(argstring, "pam | %s acct_mgmt   -- argv[%d]:%s\n", user, argc, argv[argc]);
        print_log(argstring);
    }
}


PAM_EXTERN int pam_sm_open_session(pam_handle_t *pamh, int flags, int argc, const char **argv) {
    if (flags == PAM_SILENT) {
        return PAM_IGNORE;
    }

    const char* user;
    pam_get_user(pamh,&user,NULL);

    print_status("open_session", user, flags, argc, argv);

    char cmd[1024];
    sprintf(cmd, "eta-kisit --user-login %s", user);
    system(cmd);

    return PAM_IGNORE;
}

PAM_EXTERN int pam_sm_close_session(pam_handle_t *pamh, int flags, int argc, const char **argv) {
    if (flags == PAM_SILENT) {
        return PAM_IGNORE;
    }
    
    const char* user;
    pam_get_user(pamh,&user,NULL);

    print_status("close_session", user, flags, argc, argv);
    
    char cmd[1024];
    sprintf(cmd, "eta-kisit --user-logout %s", user);
    system(cmd);

    return PAM_IGNORE;
}
PAM_EXTERN int pam_sm_authenticate(pam_handle_t *pamh, int flags, int argc, const char **argv) {
    if (flags == PAM_SILENT) {
        return PAM_IGNORE;
    }
    
    const char* user;
    pam_get_user(pamh,&user,NULL);

    print_status("authenticate", user, flags, argc, argv);
    
    char cmd[1024];
    sprintf(cmd, "eta-kisit --user-login %s", user);
    system(cmd);

    return PAM_IGNORE;
}

/*
PAM_EXTERN int pam_sm_acct_mgmt(pam_handle_t *pamh, int flags, int argc, const char **argv) {
    const char* user;
    pam_get_user(pamh,&user,NULL);

    print_status("acct_mgmt", user, flags, argc, argv);

    return PAM_IGNORE;
}
*/