#!/usr/bin/python3
import gi
import sys
import argparse
import managers.FileRestrictionManager as FileRestrictionManager
import ETAKisitActivator

# Privileged run check
if not FileRestrictionManager.check_user_privileged():
    sys.stderr.write("You are not privileged to run this script.\n")
    sys.exit(1)

gi.require_version("Gtk", "3.0")
from gi.repository import Gtk, Gio  # noqa
from ui_gtk3.MainWindow import MainWindow  # noqa
import Logger  # noqa


class Main(Gtk.Application):
    def __init__(self):
        super().__init__(
            application_id="tr.org.pardus.eta-kisit",
            flags=Gio.ApplicationFlags.FLAGS_NONE,
        )

        self.window = None

    def do_activate(self):
        if self.window is None:
            self.window = MainWindow(self)

        self.window.show_ui()


# Argument Parsing
parser = argparse.ArgumentParser(description="Application & Domain restricting app.")

parser.add_argument(
    "--reload", action="store_true", help="Apply new profiles.json to the system."
)
parser.add_argument(
    "--user-login",
    action="store",
    help="Specify a user logged in. This disables network restrictions if user is a privileged user.",
)
parser.add_argument(
    "--user-logout",
    action="store",
    help="Specify a user logged out. This re-enables network restrictions if user is a unprivileged user.",
)
parser.add_argument(
    "--generate-applist",
    action="store_true",
    help='Write installed applications in "/var/lib/eta/eta-kisit/installed_applications.json"',
)
args = parser.parse_args()


if args.reload:
    # Deactive
    print("Reverting previous settings...")
    ETAKisitActivator.run_activator(["--unrestrict"])

    print("Applying new settings...")
    ETAKisitActivator.run_activator(["--restrict"])

    print("Done.")
elif args.user_login:
    if not ETAKisitActivator.is_service_active():
        exit(0)

    import managers.ProfileManager as ProfileManager

    username = args.user_login

    Logger.log("login, username: {}".format(username))
    if username == "ogrenci":
        ETAKisitActivator.run_activator(["--enable-websites-restriction"])
        exit(0)
    else:
        ETAKisitActivator.run_activator(["--disable-websites-restriction"])

    profile_manager = ProfileManager.get_default()
    try:
        user_profile = profile_manager.get_profile(username)
        print("Profile found:", username)
        if user_profile.get_activate_on_startup():
            Logger.log("'activate_on_startup' is true, activating: {}".format(username))
            # Deactive
            print("Reverting previous settings...")
            ETAKisitActivator.run_activator(["--unrestrict"])

            profile_manager.set_current_profile(username)

            print("Applying new settings...")
            ETAKisitActivator.run_activator(["--restrict"])

            print("Done.")

        else:
            print(
                "Profile found but 'activate_on_startup' property is false. Nothing changed."
            )
    except KeyError:
        # No profile found, create a new one
        profile_manager.insert_default_profile(username)
        print("Profile not found, creating new one:", username)
elif args.user_logout:
    if not ETAKisitActivator.is_service_active():
        exit(0)

    import managers.ProfileManager as ProfileManager

    username = args.user_logout

    Logger.log("logout, active_session_username: {}".format(username))
    if username == "ogrenci":
        ETAKisitActivator.run_activator(["--disable-websites-restriction"])
        exit(0)
elif args.generate_applist:
    import managers.ApplicationManager as ApplicationManager

    ApplicationManager.save_all_applications()
    print(
        "Applications saved to {}".format(
            ApplicationManager.INSTALLED_APPLICATIONS_PATH
        )
    )
else:
    # Start GUI
    app = Main()
    app.run(sys.argv)
